pub struct VaultMintRequest {
pub vault_id: u32,
pub symbol: String,
pub quantity: Decimal,
pub auto_borrow: Option<bool>,
pub auto_lend_redeem: Option<bool>,
}Expand description
Request payload for minting vault tokens.
Fields
vault_id: u32The vault ID to mint tokens from.
symbol: StringThe symbol of the asset to deposit.
quantity: DecimalAmount to deposit.
auto_borrow: Option<bool>Whether to allow auto borrowing when depositing into vault.
auto_lend_redeem: Option<bool>Whether to allow auto redeem lent assets when depositing into vault.